==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2206_162.zip: ronportal/ronportal/elearning/view_kurz.php <==
<?php
/**
 * stanislav.elbl, 08.07.2015
 */

namespace RonPortal\ELearning;

use Ron\Http\App;
use Ron\MVC\Model;
use Ron\StringUtils;
use Ron\TextManager;
use RonPortal\Prava;

$pravoEditace = Prava::vratHodnotuPrava('editacekurzu');

$model = Model::getInstance();

/** @var Kurz $kurz  */
$kurz = $model['kurz'];
/** @var RevizeEKurzu $revize */
$revize = $model['revize'];

/** @var string $action */
$action = $model['action'];

// vybere aktualni zalozku
$tab = 'kurz_basic';
switch (isset($_GET['tab']) ? $_GET['tab'] : 'basic') {
    case 'content' :    $tab = 'kurz_text'; break;
    case 'properties' : $tab = 'kurz_podrobnosti_stranky'; break;
    case 'tests' :      $tab = 'kurz_testy'; break;
}

$config = [
    "urlDownload" => KurzyController::URL_DOWNLOAD
];

?>

<h1 id="elearning_nadpis"><?= StringUtils::htmlTextConvert($kurz ->getNazev()) ?></h1>

<div id="elearning_container">

    <!-- osnova - seznam kapitol -->
    <div id="elearning_osnova">
        <ul id="elearning_menu_osnova" class="linkslist">
            <li><a id="kurz_new_content"><?= TextManager::_('Pridat_stranku_kurzu') ?></a></li>
        </ul>

        <ul class="elearning_menu_list" id="kurz_obsah_list">
        </ul>

        <i class="fa fa-spin glyph-spinner position-absolute position-top position-right margin-all-2 loading-indicator"></i>
    </div>

    <ul id="kurz_osnova_menu" class="popupmenu">
        <li data-ron-akce="editovat"><?= TextManager::_('Editovat_text') ?></li>
        <li data-ron-akce="vlastnosti"><?= TextManager::_('Vlastnosti_obsahu') ?></li>
        <li data-ron-akce="odstranit"><?= TextManager::_('Odstranit_stranu') ?></li>
    </ul>

    <!-- data - jednotlive zalozky -->
    <div id="elearning_data">

        <div>
            <ul class="linkslist float-right">
                <li><a target="_blank" href="?menuid=prezentace&revize=<?= $revize ->getId() ?>"><?= TextManager::_('Prezentace') ?></a></li>
                <li><a id="kurz_menu_back" href="?menuid=kurzy"><?= TextManager::_('Zpet_na_seznam') ?></a></li>
            </ul>

            <ul id="elearning_tabs">
                <li data-ron-tab="kurz_basic">
                    <a id="kurz_menu_basic" href="?menuid=kurzy&action=show&record=<?= $kurz ->getId() ?>"><?= TextManager::_('Zakladni_informace_o_kurzu') ?></a>
                </li>
                <li data-ron-tab="kurz_text">
                    <a id="kurz_menu_text" href="?menuid=kurzy&action=show&record=<?= $kurz ->getId() ?>&tab=content"><?= TextManager::_('Text_strany_kurzu') ?></a>
                </li>
                <li data-ron-tab="kurz_podrobnosti_stranky">
                    <a id="kurz_menu_properties" href="?menuid=kurzy&action=show&record=<?= $kurz ->getId() ?>&tab=properties"><?= TextManager::_('Vlastnosti_obsahu') ?></a>
                </li>
                <li data-ron-tab="kurz_testy">
                    <a id="kurz_menu_tests" href="?menuid=kurzy&action=show&record=<?= $kurz ->getId() ?>&tab=tests"><?= TextManager::_('Testy_kurzu') ?></a>
                </li>
            </ul>
        </div>

        <div id="kurz_obsah">
            <!-- zaklani informace o kurzu -->
            <div id="kurz_basic">
                <div class="form middle-form form-30-70">
                    <div class="form-content">
                    <div class="form-row">
                        <div class="form-col form-col1 caption"><?= TextManager::_('Platnost_od') ?></div>
                        <div class="form-col form-col2"><?= date('j.n.Y', $kurz ->getPlatnostOd()); ?>
                            <?php if ($kurz ->getPlatnostDo()) { ?>
                                <?= TextManager::_('Do') ?> <?= date('j.n.Y', $kurz ->getPlatnostDo()) ?>
                            <?php } ?>
                        </div>
                    </div>

                    <div class="form-row">
                        <div class="form-col form-col1 caption"><?= TextManager::_('Stav_kurzu') ?></div>
                        <div class="form-col form-col2"><?= TextManager::_('Kurz_Stav_' . (int)$kurz ->getStav()) ?></div>
                    </div>

                    <?php if ($kurz ->getPopis()) { ?>
                        <div class="form-row">
                            <div class="form-col form-col1 caption"><?= TextManager::_('Popis') ?></div>
                            <div class="form-col form-col2"><?= StringUtils::longTextToHtml($kurz ->getPopis(), true) ?></div>
                        </div>
                    <?php } ?>

                    <?php if ($pravoEditace) { ?>
                        <div class="form-row">
                            <div class="form-col form-col1 caption"><?= TextManager::_('Poznamka') ?></div>
                            <div class="form-col form-col2"><?= StringUtils::longTextToHtml($kurz ->getPoznamka(), true) ?></div>
                        </div>

                        <div class="form-row">
                            <div class="form-col form-col1 caption"></div>
                            <div class="form-col form-col2"><a href="?menuid=kurzy&formaction=edit&record=<?= $kurz ->getId() ?>"><?= TextManager::_('Upravit') ?></a></div>
                        </div>

                        <div class="form-row form-section">
                            <?= TextManager::_('Revize') ?>
                        </div>

                        <div class="form-row">
                            <div class="form-col form-col12 padding-left">
                                <?php foreach ($kurz ->getRevize() as $revize) { ?>
                                    <div>
                                        <?= date('j.n.Y', $revize ->getPlatnostOd()) ?>
                                        <?= $revize ->getPlatnostDo() ? ' - ' . date('j.n.Y', $revize ->getPlatnostDo()) : '' ?>
                                        -
                                        <?= $revize ->getPopis() ?>
                                    </div>
                                <?php } ?>
                            </div>
                        </div>

                    <?php } ?>
                    </div>
                </div>
            </div>

            <!-- text stranky -->
            <div id="kurz_text" style="display: none">
                <textarea name="obsahKurzu" id="kurz_editace" class="editor">
                </textarea>
            </div>

            <!-- vlastnosti stranky -->
            <div id="kurz_podrobnosti_stranky" style="display: none;">
                <div class="form form-30-70 large-form">
                    <div class="form-content">
                        <div class="form-row">
                            <div class="form-col1 caption">
                                <?= TextManager::_('Nazev_strany') ?>
                            </div>
                            <div class="form-col2">
                                <input name="page_title" id="kurz_page_title" value="..." class="form-input">
                            </div>
                        </div>

                        <div class="form-row">
                            <div class="form-col1 caption">
                                <?= TextManager::_('Kod_strany') ?>
                            </div>
                            <div class="form-col2">
                                <input name="page_code" id="kurz_page_code" value="" size="30">
                                <span class="forminfotext"><?= TextManager::_('Kod_strany_info') ?></span>
                            </div>
                        </div>

                        <div class="form-row">
                            <div class="form-col1 caption">
                                <?= TextManager::_('Zobrazit_hlavicku') ?>
                            </div>
                            <div class="form-col2">
                                <input name="page_show_header" type="checkbox" id="kurz_page_show_header" checked="checked">
                            </div>
                        </div>

                        <div class="form-row">
                            <div class="form-col1 caption">
                                <?= TextManager::_('Zobrazit_paticku') ?>
                            </div>
                            <div class="form-col2">
                                <input name="page_show_footer" type="checkbox" id="kurz_page_show_footer" checked="checked">
                            </div>
                        </div>

                        <!--
                        TODO: barva pozadi?
                        -->
                        <div class="form-row">
                            <div class="form-col1 caption">
                                <label for="test_obsahu"><?= TextManager::_('Test') ?></label>
                            </div>
                            <div class="form-col2">
                                <select id="test_obsahu"></select>
                            </div>
                        </div>
                    </div>

                    <div class="buttons">
                        <input type="submit" id="btn_podrobnosti_strany_OK" class="submitbutton" value="<?= TextManager::_('form.Store') ?>" />
                    </div>
                </div>
                <!--
                <div class="buttons">
                </div>
                -->

            </div>

            <div id="kurz_testy" style="display: none">
                <table class="browser rowOver">
                    <tr>
                        <th><?= TextManager::_('Kod') ?></th>
                        <th><?= TextManager::_('Popis') ?></th>
                        <th><!-- buttonky --></th>
                    </tr>
                    <tbody id="seznamPripojenychTestu">

                    </tbody>
                </table>
                <div class="padding-top">
                    <a id="pripojitNovyTest" href="#"><?= TextManager::_('Pripojit_novy_test') ?></a>
                </div>
            </div>
        </div>

        <!-- image upload -->
        <iframe id="image_upload_target" name="image_upload_target" style="<?= App::getDebugMode() ? 'width:800px; height:200px' : 'display:none' ?>"></iframe>
        <form id="image_upload_form" action="?menuid=kurzy&action=uploadform&revize=<?= $revize->getId() ?>" target="image_upload_target" method="post" enctype="multipart/form-data" style="width:0;height:0;overflow:hidden">
            <input name="upload_file" id="image_upload_form_input" type="file" />
        </form>

    </div>

    <!-- prilohy -->
    <div id="elearning_prilohy">
        <div class="inputtablesection"><?= TextManager::_('Prilohy') ?></div>
<!--        <a href="">--><?//= TextManager::_('Pridat_prilohu') ?><!--</a>-->
        <ul class="elearning_menu_list media-list" id="kurz_prilohy" data-id-revize="<?= $revize ->getId() ?>">
        </ul>

        <i class="fa fa-spin glyph-spinner position-absolute position-top position-right margin-all-2 loading-indicator"></i>
    </div>

</div>

<ul id="prilohy_menu" class="popupmenu">
    <li data-ron-akce="zobrazit"><?= TextManager::_('Zobrazit_prilohu') ?></li>
    <li data-ron-akce="odstranit"><?= TextManager::_('Odstranit_prilohu') ?></li>
</ul>

<div style="display: none" class="prilohyView">
    <div id="prevImage"></div>
    <div id="actualImage"></div>
    <div id="nextImage"></div>
</div>

<!-- dialog - vytvoreni noveho testu -->
<div id="novyTestDialog" style="display:none" title="<?= TextManager::_('Novy_test') ?>">
    <table>
        <tr>
            <td class="formtablecaption"><label for="kodNovehoTestu"><?= TextManager::_('Kod') ?></label></td>
            <td><input id="kodNovehoTestu" maxlength="20"></td>
        </tr>
        <tr>
            <td class="formtablecaption"><label for="popisNovehoTestu"><?= TextManager::_('Popis') ?></label></td>
            <td><input id="popisNovehoTestu" size="80" maxlength="120"></td>
        </tr>
    </table>

    <div class="buttons align-center">
        <input id="novyTestOK" type="button" class="submitbutton" value="<?= TextManager::_('OK') ?>" />
        <input id="novyTestStorno" type="button" class="button" value="<?= TextManager::_('Cancel') ?>" />
    </div>
</div>

<script type="text/javascript">
    $( function() { ronPortal.elearning.configEditace(<?= json_encode($config) ?>); } );
    $( function() { ronPortal.elearning.initEditaceKurzu(<?= json_encode($revize ->getJson()); ?>, <?= json_encode($tab) ?>); } );
</script>

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2311_175.zip: ronportal/ronportal/elearning/view_kurz.php <==
<?php
/**
 * stanislav.elbl, 08.07.2015
 */

namespace RonPortal\ELearning;

use Ron\Http\App;
use Ron\MVC\Model;
use Ron\StringUtils;
use Ron\TextManager;
use RonPortal\Prava;

$pravoEditace = Prava::vratHodnotuPrava('editacekurzu');

$model = Model::getInstance();

/** @var Kurz $kurz  */
$kurz = $model['kurz'];
/** @var RevizeEKurzu $revize */
$revize = $model['revize'];

/** @var string $action */
$action = $model['action'];

// vybere aktualni zalozku
$tab = 'kurz_basic';
switch (isset($_GET['tab']) ? $_GET['tab'] : 'basic') {
    case 'content' :    $tab = 'kurz_text'; break;
    case 'properties' : $tab = 'kurz_podrobnosti_stranky'; break;
    case 'tests' :      $tab = 'kurz_testy'; break;
}

$config = [
    "urlDownload" => KurzyController::URL_DOWNLOAD
];

?>

<h1 id="elearning_nadpis"><?= StringUtils::htmlTextConvert($kurz ->getNazev()) ?></h1>

<div id="elearning_container" data-url-download="<?= KurzyController::URL_DOWNLOAD ?>">

    <!-- osnova - seznam kapitol -->
    <div id="elearning_osnova">
        <ul id="elearning_menu_osnova" class="linkslist">
            <li><a id="kurz_new_content"><?= TextManager::_('Pridat_stranku_kurzu') ?></a></li>
        </ul>

        <ul class="elearning_menu_list" id="kurz_obsah_list">
        </ul>

        <i class="fa fa-spin glyph-spinner position-absolute position-top position-right margin-all-2 loading-indicator"></i>
    </div>

    <ul id="kurz_osnova_menu" class="popupmenu">
        <li data-ron-akce="editovat"><?= TextManager::_('Editovat_text') ?></li>
        <li data-ron-akce="vlastnosti"><?= TextManager::_('Vlastnosti_obsahu') ?></li>
        <li data-ron-akce="odstranit"><?= TextManager::_('Odstranit_stranu') ?></li>
    </ul>

    <!-- data - jednotlive zalozky -->
    <div id="elearning_data">

        <div>
            <ul class="linkslist float-right">
                <li><a target="_blank" href="?menuid=prezentace&revize=<?= $revize ->getId() ?>"><?= TextManager::_('Prezentace') ?></a></li>
                <li><a id="kurz_menu_back" href="?menuid=kurzy"><?= TextManager::_('Zpet_na_seznam') ?></a></li>
            </ul>

            <ul id="elearning_tabs">
                <li data-ron-tab="kurz_basic">
                    <a id="kurz_menu_basic" href="?menuid=kurzy&action=show&record=<?= $kurz ->getId() ?>"><?= TextManager::_('Zakladni_informace_o_kurzu') ?></a>
                </li>
                <li data-ron-tab="kurz_text">
                    <a id="kurz_menu_text" href="?menuid=kurzy&action=show&record=<?= $kurz ->getId() ?>&tab=content"><?= TextManager::_('Text_strany_kurzu') ?></a>
                </li>
                <li data-ron-tab="kurz_podrobnosti_stranky">
                    <a id="kurz_menu_properties" href="?menuid=kurzy&action=show&record=<?= $kurz ->getId() ?>&tab=properties"><?= TextManager::_('Vlastnosti_obsahu') ?></a>
                </li>
                <li data-ron-tab="kurz_testy">
                    <a id="kurz_menu_tests" href="?menuid=kurzy&action=show&record=<?= $kurz ->getId() ?>&tab=tests"><?= TextManager::_('Testy_kurzu') ?></a>
                </li>
            </ul>
        </div>

        <div id="kurz_obsah">
            <!-- zaklani informace o kurzu -->
            <div id="kurz_basic">
                <div class="form middle-form form-30-70">
                    <div class="form-content">
                    <div class="form-row">
                        <div class="form-col form-col1 caption"><?= TextManager::_('Platnost_od') ?></div>
                        <div class="form-col form-col2"><?= date('j.n.Y', $kurz ->getPlatnostOd()); ?>
                            <?php if ($kurz ->getPlatnostDo()) { ?>
                                <?= TextManager::_('Do') ?> <?= date('j.n.Y', $kurz ->getPlatnostDo()) ?>
                            <?php } ?>
                        </div>
                    </div>

                    <div class="form-row">
                        <div class="form-col form-col1 caption"><?= TextManager::_('Stav_kurzu') ?></div>
                        <div class="form-col form-col2"><?= TextManager::_('Kurz_Stav_' . (int)$kurz ->getStav()) ?></div>
                    </div>

                    <?php if ($kurz ->getPopis()) { ?>
                        <div class="form-row">
                            <div class="form-col form-col1 caption"><?= TextManager::_('Popis') ?></div>
                            <div class="form-col form-col2"><?= StringUtils::longTextToHtml($kurz ->getPopis(), true) ?></div>
                        </div>
                    <?php } ?>

                    <?php if ($pravoEditace) { ?>
                        <div class="form-row">
                            <div class="form-col form-col1 caption"><?= TextManager::_('Poznamka') ?></div>
                            <div class="form-col form-col2"><?= StringUtils::longTextToHtml($kurz ->getPoznamka(), true) ?></div>
                        </div>

                        <div class="form-row">
                            <div class="form-col form-col1 caption"></div>
                            <div class="form-col form-col2"><a href="?menuid=kurzy&formaction=edit&record=<?= $kurz ->getId() ?>"><?= TextManager::_('Upravit') ?></a></div>
                        </div>

                        <div class="form-row form-section">
                            <?= TextManager::_('Revize') ?>
                        </div>

                        <div class="form-row">
                            <div class="form-col form-col12 padding-left">
                                <?php foreach ($kurz ->getRevize() as $revize) { ?>
                                    <div>
                                        <?= date('j.n.Y', $revize ->getPlatnostOd()) ?>
                                        <?= $revize ->getPlatnostDo() ? ' - ' . date('j.n.Y', $revize ->getPlatnostDo()) : '' ?>
                                        -
                                        <?= $revize ->getPopis() ?>
                                    </div>
                                <?php } ?>
                            </div>
                        </div>

                    <?php } ?>
                    </div>
                </div>
            </div>

            <!-- text stranky -->
            <div id="kurz_text" style="display: none">
                <textarea name="obsahKurzu" id="kurz_editace" class="editor">
                </textarea>
            </div>

            <!-- vlastnosti stranky -->
            <div id="kurz_podrobnosti_stranky" style="display: none;">
                <div class="form form-30-70 large-form">
                    <div class="form-content">
                        <div class="form-row">
                            <div class="form-col1 caption">
                                <?= TextManager::_('Nazev_strany') ?>
                            </div>
                            <div class="form-col2">
                                <input name="page_title" id="kurz_page_title" value="..." class="form-input">
                            </div>
                        </div>

                        <div class="form-row">
                            <div class="form-col1 caption">
                                <?= TextManager::_('Kod_strany') ?>
                            </div>
                            <div class="form-col2">
                                <input name="page_code" id="kurz_page_code" value="" size="30">
                                <span class="forminfotext"><?= TextManager::_('Kod_strany_info') ?></span>
                            </div>
                        </div>

                        <div class="form-row">
                            <div class="form-col1 caption">
                                <?= TextManager::_('Zobrazit_hlavicku') ?>
                            </div>
                            <div class="form-col2">
                                <input name="page_show_header" type="checkbox" id="kurz_page_show_header" checked="checked">
                            </div>
                        </div>

                        <div class="form-row">
                            <div class="form-col1 caption">
                                <?= TextManager::_('Zobrazit_paticku') ?>
                            </div>
                            <div class="form-col2">
                                <input name="page_show_footer" type="checkbox" id="kurz_page_show_footer" checked="checked">
                            </div>
                        </div>

                        <!--
                        TODO: barva pozadi?
                        -->
                        <div class="form-row">
                            <div class="form-col1 caption">
                                <label for="test_obsahu"><?= TextManager::_('Test') ?></label>
                            </div>
                            <div class="form-col2">
                                <select id="test_obsahu"></select>
                            </div>
                        </div>

                        <div class="form-row">
                            <div class="form-col1 caption">
                                <?= TextManager::_('Povolit_pokracovat_bez_absolvovani') ?>
                            </div>
                            <div class="form-col2">
                                <input name="page_povolit_pokracovat" type="checkbox" id="kurz_page_povolit_pokracovat">
                            </div>
                        </div>
                    </div>

                    <div class="buttons">
                        <input type="submit" id="btn_podrobnosti_strany_OK" class="submitbutton" value="<?= TextManager::_('form.Store') ?>" />
                    </div>
                </div>
                <!--
                <div class="buttons">
                </div>
                -->

            </div>

            <div id="kurz_testy" style="display: none">
                <table class="browser rowOver">
                    <tr>
                        <th><?= TextManager::_('Kod') ?></th>
                        <th><?= TextManager::_('Popis') ?></th>
                        <th><!-- buttonky --></th>
                    </tr>
                    <tbody id="seznamPripojenychTestu">

                    </tbody>
                </table>
                <div class="padding-top">
                    <a id="pripojitNovyTest" href="#"><?= TextManager::_('Pripojit_novy_test') ?></a>
                </div>
            </div>
        </div>

        <!-- image upload -->
        <iframe id="image_upload_target" name="image_upload_target" style="<?= App::getDebugMode() ? 'width:800px; height:200px' : 'display:none' ?>"></iframe>
        <form id="image_upload_form" action="?menuid=kurzy&action=uploadform&revize=<?= $revize->getId() ?>" target="image_upload_target" method="post" enctype="multipart/form-data" style="width:0;height:0;overflow:hidden">
            <input name="upload_file" id="image_upload_form_input" type="file" />
        </form>

    </div>

    <!-- prilohy -->
    <div id="elearning_prilohy">
        <div class="inputtablesection"><?= TextManager::_('Prilohy') ?></div>
<!--        <a href="">--><?//= TextManager::_('Pridat_prilohu') ?><!--</a>-->
        <ul class="elearning_menu_list media-list" id="kurz_prilohy" data-id-revize="<?= $revize ->getId() ?>">
        </ul>

        <i class="fa fa-spin glyph-spinner position-absolute position-top position-right margin-all-2 loading-indicator"></i>
    </div>

</div>

<ul id="prilohy_menu" class="popupmenu">
    <li data-ron-akce="zobrazit"><?= TextManager::_('Zobrazit_prilohu') ?></li>
    <li data-ron-akce="odstranit"><?= TextManager::_('Odstranit_prilohu') ?></li>
</ul>

<div style="display: none" class="prilohyView">
    <div id="prevImage"></div>
    <div id="actualImage"></div>
    <div id="nextImage"></div>
</div>

<!-- dialog - vytvoreni noveho testu -->
<div id="novyTestDialog" style="display:none" title="<?= TextManager::_('Novy_test') ?>">
    <table>
        <tr>
            <td class="formtablecaption"><label for="kodNovehoTestu"><?= TextManager::_('Kod') ?></label></td>
            <td><input id="kodNovehoTestu" maxlength="20"></td>
        </tr>
        <tr>
            <td class="formtablecaption"><label for="popisNovehoTestu"><?= TextManager::_('Popis') ?></label></td>
            <td><input id="popisNovehoTestu" size="80" maxlength="120"></td>
        </tr>
    </table>

    <div class="buttons align-center">
        <input id="novyTestOK" type="button" class="submitbutton" value="<?= TextManager::_('OK') ?>" />
        <input id="novyTestStorno" type="button" class="button" value="<?= TextManager::_('Cancel') ?>" />
    </div>
</div>

<script type="text/javascript">
    $( function() { ronPortal.elearning.initEditaceKurzu(<?= json_encode($revize ->getJson()); ?>, <?= json_encode($tab) ?>); } );
</script>
